@@ -147,7 +147,7 @@ class Users(_defaults_.Defaults):
 		# save new user data.
 		data["timestamps"]["created"] = Date().date
 		data["keys"]["api_key"] = String().generate(length=48, capitalize=True, digits=True)
-		_response_ = self.aes.encrypt(password)
+		_response_ = self.encryption.encrypt(password)
 		if not _response_.success: return _response_
 		try:data["account"]
 		except: data["account"] = {}
@@ -847,7 +847,7 @@ class Users(_defaults_.Defaults):
 		response = self.load_data(email=email, username=username)
 		if not response.success: return response
 		data = response.data
-		_response_ = self.aes.decrypt(data["account"]["password"])
+		_response_ = self.encryption.decrypt(data["account"]["password"])
 		if not _response_.success: return _response_
 		password = _response_["decrypted"].decode()
 		return Response.success(f"Successfully retrieved the password of user {email}.",{
@@ -866,7 +866,7 @@ class Users(_defaults_.Defaults):
 		response = self.load_data(email=email, username=username)
 		if not response.success: return response
 		data = response.data
-		_response_ = self.aes.encrypt(password)
+		_response_ = self.encryption.encrypt(password)
 		if not _response_.success: _response_
 		try:data["account"]
 		except: data["account"] = {}
